@@ -11,12 +11,12 @@ use Pony::Object qw/Human::Base/;
 
     sub moveRight
         {
-            --shift->x;
+            ++shift->x;
         }
     
     sub moveTop
         {
-            --shift->y;
+            ++shift->y;
         }
 
     sub moveDown
@@ -24,7 +24,7 @@ use Pony::Object qw/Human::Base/;
             --shift->y;
         }
     
-    sub getResiltWay
+    sub getResultWay
         {
             my $this = shift;
             return ( $this->x**2 + $this->y**2 )**0.5;
